@@ -60,10 +60,12 @@ from bitmovin_api_sdk.models.analytics_equal_filter import AnalyticsEqualFilter
 from bitmovin_api_sdk.models.analytics_export_status import AnalyticsExportStatus
 from bitmovin_api_sdk.models.analytics_export_task import AnalyticsExportTask
 from bitmovin_api_sdk.models.analytics_export_task_output_target import AnalyticsExportTaskOutputTarget
+from bitmovin_api_sdk.models.analytics_gcs_service_account_output import AnalyticsGcsServiceAccountOutput
 from bitmovin_api_sdk.models.analytics_greater_than_filter import AnalyticsGreaterThanFilter
 from bitmovin_api_sdk.models.analytics_greater_than_or_equal_filter import AnalyticsGreaterThanOrEqualFilter
 from bitmovin_api_sdk.models.analytics_impression_details import AnalyticsImpressionDetails
 from bitmovin_api_sdk.models.analytics_impression_list_item import AnalyticsImpressionListItem
+from bitmovin_api_sdk.models.analytics_impression_sample import AnalyticsImpressionSample
 from bitmovin_api_sdk.models.analytics_impressions_query import AnalyticsImpressionsQuery
 from bitmovin_api_sdk.models.analytics_impressions_response import AnalyticsImpressionsResponse
 from bitmovin_api_sdk.models.analytics_in_filter import AnalyticsInFilter
@@ -86,11 +88,14 @@ from bitmovin_api_sdk.models.analytics_not_contains_filter import AnalyticsNotCo
 from bitmovin_api_sdk.models.analytics_not_equal_filter import AnalyticsNotEqualFilter
 from bitmovin_api_sdk.models.analytics_order import AnalyticsOrder
 from bitmovin_api_sdk.models.analytics_order_by_entry import AnalyticsOrderByEntry
+from bitmovin_api_sdk.models.analytics_output import AnalyticsOutput
+from bitmovin_api_sdk.models.analytics_output_type import AnalyticsOutputType
 from bitmovin_api_sdk.models.analytics_percentile_query_request import AnalyticsPercentileQueryRequest
 from bitmovin_api_sdk.models.analytics_query_operator import AnalyticsQueryOperator
 from bitmovin_api_sdk.models.analytics_query_request import AnalyticsQueryRequest
 from bitmovin_api_sdk.models.analytics_query_timeframe import AnalyticsQueryTimeframe
 from bitmovin_api_sdk.models.analytics_response import AnalyticsResponse
+from bitmovin_api_sdk.models.analytics_s3_role_based_output import AnalyticsS3RoleBasedOutput
 from bitmovin_api_sdk.models.analytics_stddev_query_request import AnalyticsStddevQueryRequest
 from bitmovin_api_sdk.models.analytics_sum_query_request import AnalyticsSumQueryRequest
 from bitmovin_api_sdk.models.analytics_variance_query_request import AnalyticsVarianceQueryRequest
@@ -407,6 +412,10 @@ from bitmovin_api_sdk.models.muxing_stream import MuxingStream
 from bitmovin_api_sdk.models.muxing_type import MuxingType
 from bitmovin_api_sdk.models.mv_prediction_mode import MvPredictionMode
 from bitmovin_api_sdk.models.mxf_muxing import MxfMuxing
+from bitmovin_api_sdk.models.nex_guard_ab_watermarking_feature import NexGuardABWatermarkingFeature
+from bitmovin_api_sdk.models.nex_guard_file_marker import NexGuardFileMarker
+from bitmovin_api_sdk.models.nex_guard_watermarking_strength import NexGuardWatermarkingStrength
+from bitmovin_api_sdk.models.nex_guard_watermarking_type import NexGuardWatermarkingType
 from bitmovin_api_sdk.models.notification import Notification
 from bitmovin_api_sdk.models.notification_state_entry import NotificationStateEntry
 from bitmovin_api_sdk.models.notification_states import NotificationStates
@@ -422,6 +431,8 @@ from bitmovin_api_sdk.models.organization_type import OrganizationType
 from bitmovin_api_sdk.models.output import Output
 from bitmovin_api_sdk.models.output_type import OutputType
 from bitmovin_api_sdk.models.output_type_response import OutputTypeResponse
+from bitmovin_api_sdk.models.packed_audio_muxing import PackedAudioMuxing
+from bitmovin_api_sdk.models.packed_audio_muxing_information import PackedAudioMuxingInformation
 from bitmovin_api_sdk.models.padding_duration_unit import PaddingDurationUnit
 from bitmovin_api_sdk.models.padding_sequence import PaddingSequence
 from bitmovin_api_sdk.models.pagination_response import PaginationResponse
@@ -614,6 +625,7 @@ from bitmovin_api_sdk.models.vp9_video_configuration import Vp9VideoConfiguratio
 from bitmovin_api_sdk.models.vtt_media_info import VttMediaInfo
 from bitmovin_api_sdk.models.watermark_filter import WatermarkFilter
 from bitmovin_api_sdk.models.web_vtt_configuration import WebVttConfiguration
+from bitmovin_api_sdk.models.web_vtt_cue_identifier_policy import WebVttCueIdentifierPolicy
 from bitmovin_api_sdk.models.web_vtt_sidecar_file import WebVttSidecarFile
 from bitmovin_api_sdk.models.web_vtt_sidecar_file_segmentation import WebVttSidecarFileSegmentation
 from bitmovin_api_sdk.models.webhook import Webhook
