@@ -6,6 +6,7 @@ from bitmovin_api_sdk.common.poscheck import poscheck_model
 from bitmovin_api_sdk.models.billable_encoding_minutes_details import BillableEncodingMinutesDetails
 from bitmovin_api_sdk.models.codec_config_type import CodecConfigType
 from bitmovin_api_sdk.models.encoding_mode import EncodingMode
+from bitmovin_api_sdk.models.nex_guard_ab_watermarking_feature import NexGuardABWatermarkingFeature
 from bitmovin_api_sdk.models.psnr_per_stream_mode import PsnrPerStreamMode
 from bitmovin_api_sdk.models.statistics_per_title_stream import StatisticsPerTitleStream
 import pprint
@@ -22,8 +23,9 @@ class BillableEncodingMinutes(object):
                  preset=None,
                  live=None,
                  enhanced_deinterlace=None,
+                 nex_guard_ab_watermarking_type=None,
                  billable_minutes=None):
-        # type: (EncodingMode, CodecConfigType, StatisticsPerTitleStream, PsnrPerStreamMode, string_types, bool, bool, BillableEncodingMinutesDetails) -> None
+        # type: (EncodingMode, CodecConfigType, StatisticsPerTitleStream, PsnrPerStreamMode, string_types, bool, bool, NexGuardABWatermarkingFeature, BillableEncodingMinutesDetails) -> None
 
         self._encoding_mode = None
         self._codec = None
@@ -32,6 +34,7 @@ class BillableEncodingMinutes(object):
         self._preset = None
         self._live = None
         self._enhanced_deinterlace = None
+        self._nex_guard_ab_watermarking_type = None
         self._billable_minutes = None
         self.discriminator = None
 
@@ -49,6 +52,8 @@ class BillableEncodingMinutes(object):
             self.live = live
         if enhanced_deinterlace is not None:
             self.enhanced_deinterlace = enhanced_deinterlace
+        if nex_guard_ab_watermarking_type is not None:
+            self.nex_guard_ab_watermarking_type = nex_guard_ab_watermarking_type
         if billable_minutes is not None:
             self.billable_minutes = billable_minutes
 
@@ -62,6 +67,7 @@ class BillableEncodingMinutes(object):
             'preset': 'string_types',
             'live': 'bool',
             'enhanced_deinterlace': 'bool',
+            'nex_guard_ab_watermarking_type': 'NexGuardABWatermarkingFeature',
             'billable_minutes': 'BillableEncodingMinutesDetails'
         }
 
@@ -77,6 +83,7 @@ class BillableEncodingMinutes(object):
             'preset': 'preset',
             'live': 'live',
             'enhanced_deinterlace': 'enhancedDeinterlace',
+            'nex_guard_ab_watermarking_type': 'nexGuardABWatermarkingType',
             'billable_minutes': 'billableMinutes'
         }
         return attributes
@@ -276,6 +283,33 @@ class BillableEncodingMinutes(object):
 
         self._enhanced_deinterlace = enhanced_deinterlace
 
+    @property
+    def nex_guard_ab_watermarking_type(self):
+        # type: () -> NexGuardABWatermarkingFeature
+        """Gets the nex_guard_ab_watermarking_type of this BillableEncodingMinutes.
+
+
+        :return: The nex_guard_ab_watermarking_type of this BillableEncodingMinutes.
+        :rtype: NexGuardABWatermarkingFeature
+        """
+        return self._nex_guard_ab_watermarking_type
+
+    @nex_guard_ab_watermarking_type.setter
+    def nex_guard_ab_watermarking_type(self, nex_guard_ab_watermarking_type):
+        # type: (NexGuardABWatermarkingFeature) -> None
+        """Sets the nex_guard_ab_watermarking_type of this BillableEncodingMinutes.
+
+
+        :param nex_guard_ab_watermarking_type: The nex_guard_ab_watermarking_type of this BillableEncodingMinutes.
+        :type: NexGuardABWatermarkingFeature
+        """
+
+        if nex_guard_ab_watermarking_type is not None:
+            if not isinstance(nex_guard_ab_watermarking_type, NexGuardABWatermarkingFeature):
+                raise TypeError("Invalid type for `nex_guard_ab_watermarking_type`, type has to be `NexGuardABWatermarkingFeature`")
+
+        self._nex_guard_ab_watermarking_type = nex_guard_ab_watermarking_type
+
     @property
     def billable_minutes(self):
         # type: () -> BillableEncodingMinutesDetails
